@@ -1,5 +1,7 @@
+import base64
 import copy
 import json
+import sys
 from keen import persistence_strategies, exceptions
 from keen.api import KeenApi
 from keen.persistence_strategies import BasePersistenceStrategy
@@ -99,7 +101,7 @@ class KeenClient(object):
         self.persistence_strategy.persist(event)
 
     def add_events(self, events):
-        """ Adds a batch of events
+        """ Adds a batch of events.
 
         Depending on the persistence strategy of the client,
         this will either result in the event being uploaded to Keen
@@ -109,6 +111,44 @@ class KeenClient(object):
         """
         self.persistence_strategy.batch_persist(events)
 
+    def generate_image_beacon(self, event_collection, event_body, timestamp=None):
+        """ Generates an image beacon URL.
+
+        :param event_collection: the name of the collection to insert the
+        event to
+        :param event_body: dict, the body of the event to insert the event to
+        :param timestamp: datetime, optional, the timestamp of the event
+        """
+        event = Event(self.project_id, event_collection, event_body,
+                      timestamp=timestamp)
+        event_json = event.to_json()
+        return "{0}/{1}/projects/{2}/events/{3}?api_key={4}&data={5}".format(
+            self.api.base_url, self.api.api_version, self.project_id, self._url_escape(event_collection),
+            self.api.write_key.decode(sys.getdefaultencoding()), self._base64_encode(event_json)
+        )
+
+    def _base64_encode(self, string_to_encode):
+        """ Base64 encodes a string, with either Python 2 or 3.
+
+        :param string_to_encode: the string to encode
+        """
+        try:
+            # python 2
+            return base64.b64encode(string_to_encode)
+        except TypeError:
+            # python 3
+            encoding = sys.getdefaultencoding()
+            base64_bytes = base64.b64encode(bytes(string_to_encode, encoding))
+            return base64_bytes.decode(encoding)
+
+    def _url_escape(self, url):
+        try:
+            import urllib
+            return urllib.quote(url)
+        except AttributeError:
+            import urllib.parse
+            return urllib.parse.quote(url)
+
     def count(self, event_collection, timeframe=None, timezone=None, interval=None, filters=None, group_by=None):
         """ Performs a count query
 
